==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/DecisionMergeNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ControlNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.DecisionMergeNode;
import io.ciera.tool.sql.ooaofooa.activity.DecisionMergeNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ControlNodeSetImpl;

import java.util.Arrays;
import java.util.List;


public class DecisionMergeNodeSetImpl extends InstanceSet<DecisionMergeNodeSet,DecisionMergeNode> implements DecisionMergeNodeSet {

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( DecisionMergeNode decisionmergenode : this ) decisionmergenode.setId( ref_Id );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( DecisionMergeNode decisionmergenode : this ) decisionmergenode.setDescrip( m_Descrip );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( DecisionMergeNode decisionmergenode : this ) decisionmergenode.setName( m_Name );
    }


    // selections
    @Override
    public ControlNodeSet R1106_is_a_ControlNode() throws XtumlException {
        ControlNodeSet controlnodeset = new ControlNodeSetImpl();
        for ( DecisionMergeNode decisionmergenode : this ) controlnodeset.add( decisionmergenode.R1106_is_a_ControlNode() );
        return controlnodeset;
    }


    @Override
    public DecisionMergeNode nullElement() {
        return DecisionMergeNodeImpl.EMPTY_DECISIONMERGENODE;
    }

    @Override
    public DecisionMergeNodeSet emptySet() {
      return new DecisionMergeNodeSetImpl();
    }

    @Override
    public DecisionMergeNodeSet value() {
        return this;
    }

    @Override
    public List<DecisionMergeNode> elements() {
        DecisionMergeNode[] elements = toArray(new DecisionMergeNode[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/DecisionMergeNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ControlNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.DecisionMergeNode;
import io.ciera.tool.sql.ooaofooa.activity.DecisionMergeNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ControlNodeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class DecisionMergeNodeSetImpl extends InstanceSet<DecisionMergeNodeSet,DecisionMergeNode> implements DecisionMergeNodeSet {

    public DecisionMergeNodeSetImpl() {
    }

    public DecisionMergeNodeSetImpl(Comparator<? super DecisionMergeNode> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( DecisionMergeNode decisionmergenode : this ) decisionmergenode.setDescrip( m_Descrip );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( DecisionMergeNode decisionmergenode : this ) decisionmergenode.setId( ref_Id );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( DecisionMergeNode decisionmergenode : this ) decisionmergenode.setName( m_Name );
    }


    // selections
    @Override
    public ControlNodeSet R1106_is_a_ControlNode() throws XtumlException {
        ControlNodeSet controlnodeset = new ControlNodeSetImpl();
        for ( DecisionMergeNode decisionmergenode : this ) controlnodeset.add( decisionmergenode.R1106_is_a_ControlNode() );
        return controlnodeset;
    }


    @Override
    public DecisionMergeNode nullElement() {
        return DecisionMergeNodeImpl.EMPTY_DECISIONMERGENODE;
    }

    @Override
    public DecisionMergeNodeSet emptySet() {
      return new DecisionMergeNodeSetImpl();
    }

    @Override
    public DecisionMergeNodeSet emptySet(Comparator<? super DecisionMergeNode> comp) {
      return new DecisionMergeNodeSetImpl(comp);
    }

    @Override
    public DecisionMergeNodeSet value() {
        return this;
    }

    @Override
    public List<DecisionMergeNode> elements() {
        DecisionMergeNode[] elements = toArray(new DecisionMergeNode[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
